from requests_html import HTMLSession

class E2E(object):
   """E2E Test for Web Including Javascript"""
   def __init__(self, url):
      self.url = url
      session = HTMLSession()
      r = session.get(self.url)
      self.r = r
   def render(self):
      self.r.html.render()
   def exists(self, tag):
      if self.r.html.find(tag):
         return True
      else:
         return False
   def get_text(self, tag):
      if not self.r.html.find(tag):
         return None
      return [t.text for t in self.r.html.find(tag)]



from setuptools import setup

DESCRIPTION = 'e2etest: Simple End-to-End Test for Web'
NAME = 'e2etest'
AUTHOR = 'Yuya Sato'
AUTHOR_EMAIL = 'yuya@lapisai.com'
URL = 'https://lapisai.com/query'
LICENSE = 'CREATIVE COMMONS'
DOWNLOAD_URL = 'https://github.com/yuyalapis/e2etest/'
PACKAGES = [
    'e2etest'
]
KEYWORDS = 'e2e test End-to-End'
VERSION = '0.1.8'

setup(
    name=NAME,
    version=VERSION,
    description=DESCRIPTION,
    author=AUTHOR,
    author_email=AUTHOR_EMAIL,
    maintainer=AUTHOR,
    maintainer_email=AUTHOR_EMAIL,
    url=URL,
    download_url=DOWNLOAD_URL,
    packages=PACKAGES,
    license=LICENSE,
    keywords=KEYWORDS
)
